@@ -7,11 +7,6 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#if !GLIB_CHECK_VERSION(2,10,0)
-#define G_TYPE_INITIALLY_UNOWNED GTK_TYPE_OBJECT
-#define GInitiallyUnowned GtkObject
-#endif
-
 typedef void (*RPointerFinalizer)(void *ptr);
 typedef void* (*ElementConverter)(void *element);
 
@@ -48,10 +43,12 @@ __extension__ \
 __extension__ \
 ({ \
     guint n = 0; \
-	if (!array) \
-		NULL; \
-    while(array[n++]); \
-    _asRPrimArrayWithSize(array, n-1, TYPE); \
+    USER_OBJECT_ s = R_NilValue; \
+    if (array) { \
+      while(array[n++]); \
+      s = _asRPrimArrayWithSize(array, n-1, TYPE); \
+    } \
+    s; \
 })
 
 #define _asRPrimArrayWithSize(array, n, TYPE) \
@@ -74,10 +71,12 @@ __extension__ \
 __extension__ \
 ({ \
     guint n = 0; \
-	if (!array) \
-		NULL; \
-    while(array[n++]); \
-    _asRArrayWithSize(array, converter, n-1, TYPE, SETTER_TYPE); \
+    USER_OBJECT_ s = R_NilValue; \
+    if (array) { \
+      while(array[n++]); \
+      s = _asRArrayWithSize(array, converter, n-1, TYPE, SETTER_TYPE); \
+    } \
+    s; \
 })
 
 #define _asRArrayWithSize(array, converter, n, TYPE, SETTER_TYPE) \
@@ -179,10 +178,12 @@ __extension__ \
 __extension__ \
 ({ \
     guint n = 0; \
-	if (!array) \
-		NULL; \
-    while(array[n++]); \
-    asRPointerWithFinalizerArrayWithSize(array, type, finalizer, n-1); \
+    USER_OBJECT_ s = R_NilValue; \
+    if (array) { \
+      while(array[n++]); \
+      s = asRPointerWithFinalizerArrayWithSize(array, type, finalizer, n-1); \
+    } \
+    s; \
 })
 #define toRPointerWithFinalizerArrayWithSize(array, type, finalizer, n) \
 __extension__ \
@@ -205,10 +206,12 @@ __extension__ \
 __extension__ \
 ({ \
     int n = 0; \
-	if (!array) \
-		NULL; \
-    while(array[n++]); \
-    asRPointerWithRefArrayWithSize(array, type, n-1); \
+    USER_OBJECT_ s = R_NilValue; \
+    if (array) { \
+      while(array[n++]); \
+      s = asRPointerWithRefArrayWithSize(array, type, n-1); \
+    } \
+    s; \
 })
 #define toRPointerWithRefArrayWithSize(array, type, n) \
 __extension__ \
@@ -232,10 +235,12 @@ __extension__ \
 __extension__ \
 ({ \
     guint n = 0; \
-	if (!array) \
-		NULL; \
-    while(array[n++]); \
-    asRStructArrayWithSize(array, type, n-1); \
+    USER_OBJECT_ s = R_NilValue; \
+    if (array) { \
+      while(array[n++]); \
+      s = asRStructArrayWithSize(array, type, n-1); \
+    } \
+    s; \
 })
 #define asRStructArrayWithSize(array, type, n) \
 __extension__ \
@@ -258,10 +263,12 @@ __extension__ \
 __extension__ \
 ({ \
     int n = 0; \
-	if (!array) \
-		NULL; \
-    while(array[n++]); \
-    asREnumArrayWithSize(array, type, n-1); \
+    USER_OBJECT_ s = R_NilValue; \
+    if (array) { \
+      while(array[n++]); \
+      s = asREnumArrayWithSize(array, type, n-1); \
+    } \
+    s; \
 })
 #define asREnumArrayWithSize(array, type, n) \
 __extension__ \
@@ -327,7 +334,7 @@ gchar ** asCStringArray(USER_OBJECT_ svec);
 #define asCRaw(s_raw) (GET_LENGTH(s_raw) ? RAW(s_raw)[0] : 0)
 #define asCNumeric(s_num) (GET_LENGTH(s_num) ? REAL(s_num)[0] : 0)
 
-gchar * asCString(USER_OBJECT_ s_str);
+const gchar * asCString(USER_OBJECT_ s_str);
 gchar asCCharacter(USER_OBJECT_ s_char);
 
 #define asRLogical ScalarLogical
@@ -398,6 +405,7 @@ USER_OBJECT_ asRGSListWithSink(GSList *gslist, const gchar* type);
 /********** User Function wrappers ********/
 
 void S_GCompareFunc(gconstpointer s_a, gconstpointer s_b);
+gboolean S_GSourceFunc(gpointer data);
 
 /********** GClosure callbacks ***********/
 
@@ -491,4 +499,11 @@ USER_OBJECT_ R_getGObjectProps(USER_OBJECT_ sobj, USER_OBJECT_ argNames);
 void GSListFreeStrings(GSList *gslist);
 void GListFreeStrings(GList *glist);
 
+/* do this by name, so that it is resolved at runtime, simplifying header dependencies */
+#if GLIB_CHECK_VERSION(2,10,0)
+#define UNOWNED_TYPE_NAME "GInitiallyUnowned"
+#else
+#define UNOWNED_TYPE_NAME "GtkObject"
+#endif
+  
 #endif
