@@ -33,7 +33,7 @@ asCString(USER_OBJECT_ s_str)
 #if defined(R_VERSION) && R_VERSION >= R_Version(2, 7, 0)
   return(translateCharUTF8(s_str));
 #else
-  return(s_str);
+  return(CHAR_DEREF(s_str));
 #endif
   /*return(CHAR_DEREF(STRING_ELT(s_str, 0)));*/
 }
